pub struct EnabledToken {
_hidden: (),
}Expand description
Token indicating that memory quota tracking is enabled, at both compile and runtime
If support is compiled in this is a unit.
If the memquota cargo feature is not enabled, this type is uninhabited.
Scattering values of this type around in relevant data structures
and parameters lists
allows the compiler to eliminate the unwanted code.
Fields
Make non-exhaustive even within the crate
Implementations
Sourceimpl EnabledToken
impl EnabledToken
Sourcepub const fn new_if_compiled_in() -> Option<Self>
pub const fn new_if_compiled_in() -> Option<Self>
Obtain an EnabledToken if memory-tracking is compiled in, or None otherwise