macro_rules! memory_cost_structural_tuples {
{
// Recursive case: do base case for this input, and then the next inputs
$($T:ident)* - $U0:ident $($UN:ident)*
} => { ... };
{
// Base case, implement for the tuple with contents types $T
$($T:ident)* -
} => { ... };
}Expand description
Implement HasMemoryCost for tuples